<?php
/**
 * Adds the header options sections, settings, and controls to the theme customizer
 *
 * @package Stygian
 */

class Stygian_Light_Header_Options {
	public function __construct() {
		// Register Header Options.
		add_action( 'customize_register', array( $this, 'register_header_options' ) );

		// Add default options.
		add_filter( 'stygian_customizer_defaults', array( $this, 'add_defaults' ) );
	}

	/**
	 * Add options to defaults
	 */
	public function add_defaults( $default_options ) {
		$defaults = array(
			'stygian_header_style'            => 'header-six',
			'stygian_header_top_color_scheme' => 'dark-top-header', 
		);

		$updated_defaults = wp_parse_args( $defaults, $default_options );

		return $updated_defaults;
	}

	/**
	 * Add header options section and its controls
	 */
	public function register_header_options( $wp_customize ) {
		Stygian_Customizer_Utilities::register_option(
			array(
				'custom_control'    => 'Stygian_Image_Radio_Button_Custom_Control',
				'settings'          => 'stygian_header_style',
				'sanitize_callback' => 'stygian_radio_sanitization',
				'label'             => esc_html__( 'Header Style', 'stygian-light' ),
				'section'           => 'stygian_header_options',
				'choices'           => array(
					'header-one'   => array(
						'image' => trailingslashit( get_stylesheet_directory_uri() ) . 'images/header-1.png',
						'name'  => esc_html__( 'Header Style Default', 'stygian-light' ),
					),
					'header-six'   => array(
						'image' => trailingslashit( get_stylesheet_directory_uri() ) . 'images/header-6.png',
						'name'  => esc_html__( 'Header Style Light', 'stygian-light' ),
					)
				),
			)
		);

		Stygian_Customizer_Utilities::register_option(
			array(
				'type'              => 'radio',
				'settings'          => 'stygian_header_top_color_scheme',
				'sanitize_callback' => 'stygian_sanitize_select',
				'label'             => esc_html__( 'Header Top Color', 'stygian-light' ),
				'section'           => 'stygian_header_options',
				'choices'           => array(
					'dark-top-header'  => esc_html__( 'Dark', 'stygian-light' ),
					'light-top-header' => esc_html__( 'Light', 'stygian-light' ),
				),
			)
		);
	}
}

/**
 * Initialize class
 */
$stygian_light_header_options = new Stygian_Light_Header_Options();
